// Borrowed from `graphql-request`
import { __rest } from "tslib";
import fetch from 'node-fetch';
import { ClientError } from './types';
export { ClientError } from './types';
export class GraphQLClient {
    constructor(url, options) {
        this.url = url;
        this.options = options || {};
    }
    async rawRequest(query, variables) {
        const _a = this.options, { headers } = _a, others = __rest(_a, ["headers"]);
        const body = JSON.stringify({
            query,
            variables: variables ? variables : undefined,
        });
        const response = await fetch(this.url, Object.assign({ method: 'POST', headers: Object.assign({ 'Content-Type': 'application/json' }, headers), body }, others));
        const result = await getResult(response);
        if (response.ok && !result.errors && result.data) {
            const { headers, status } = response;
            return Object.assign(Object.assign({}, result), { headers, status });
        }
        else {
            const errorResult = typeof result === 'string' ? { error: result } : result;
            throw new ClientError(Object.assign(Object.assign({}, errorResult), { status: response.status, headers: response.headers }), { query, variables });
        }
    }
    async request(query, variables) {
        const _a = this.options, { headers } = _a, others = __rest(_a, ["headers"]);
        const body = JSON.stringify({
            query,
            variables: variables ? variables : undefined,
        });
        const response = await fetch(this.url, Object.assign({ method: 'POST', headers: Object.assign({ 'Content-Type': 'application/json' }, headers), body }, others));
        const result = await getResult(response);
        if (response.ok && !result.errors && result.data) {
            return result.data;
        }
        else {
            const errorResult = typeof result === 'string' ? { error: result } : result;
            throw new ClientError(Object.assign(Object.assign({}, errorResult), { status: response.status }), { query, variables });
        }
    }
    setHeaders(headers) {
        this.options.headers = headers;
        return this;
    }
    setHeader(key, value) {
        const { headers } = this.options;
        if (headers) {
            headers[key] = value;
        }
        else {
            this.options.headers = { [key]: value };
        }
        return this;
    }
}
export async function rawRequest(url, query, variables) {
    const client = new GraphQLClient(url);
    return client.rawRequest(query, variables);
}
export async function request(url, query, variables) {
    const client = new GraphQLClient(url);
    return client.request(query, variables);
}
export default request;
async function getResult(response) {
    const contentType = response.headers.get('Content-Type');
    if (contentType && contentType.startsWith('application/json')) {
        return response.json();
    }
    else {
        return response.text();
    }
}
//# sourceMappingURL=index.js.map