/**
 * This module is for reporting issues about Nexus. It extracts diagnostics
 * about the proejct and environment and can format them for a GitHub issue.
 */
import os from 'os';
import * as PluginWorktime from './plugin/worktime';
import * as PluginRuntime from './plugin';
/**
 * Extract diagnostics about the Nexus project.
 */
export async function getNexusReport(layout) {
    var _a, _b, _c, _d;
    const pj = (_a = layout.packageJson) === null || _a === void 0 ? void 0 : _a.content;
    const deps = (_b = pj === null || pj === void 0 ? void 0 : pj.dependencies) !== null && _b !== void 0 ? _b : {};
    const otherDeps = Object.fromEntries(Object.entries(deps).filter((ent) => {
        return ent[0] !== 'nexus' && !ent[0].startsWith('nexus-plugin');
    }));
    const pluginEntrypoints = await PluginWorktime.getUsedPlugins(layout);
    const gotManifests = PluginRuntime.getPluginManifests(pluginEntrypoints);
    return {
        node: process.version,
        nexus: (_c = deps.nexus) !== null && _c !== void 0 ? _c : 'undefined',
        plugins: gotManifests.data.map((m) => m.name),
        os: {
            platform: os.platform(),
            release: os.release(),
        },
        otherDependencies: otherDeps,
        devDependencies: (_d = pj === null || pj === void 0 ? void 0 : pj.devDependencies) !== null && _d !== void 0 ? _d : {},
        hasAppModule: layout.data.app.exists,
        packageManager: layout.packageManagerType,
        errorsWhileGatheringReport: {
            gettingPluginManifests: gotManifests.errors
                ? gotManifests.errors.map((e) => { var _a; return (_a = e.stack) !== null && _a !== void 0 ? _a : e.message; })
                : null,
        },
    };
}
//# sourceMappingURL=report.js.map